import React, { useState, useEffect, useRef } from "react";
import planData from "./plan.json";
import Layout from "../components/layouts/layout";

import Prismic from "prismic-javascript";
import { Date, Link, RichText } from "prismic-reactjs";
import { useRouter } from "next/router";
import ErrorPage from "./404";

const apiEndpoint = "https://servers-api.cdn.prismic.io/api/v2";
// const accessToken = ""; // This is where you would add your access token for a Private repository

// const Client = Prismic.client(apiEndpoint, { accessToken });
const Client = Prismic.client(apiEndpoint);

export default function Product() {
  const [ProductData, setProductData] = useState(null);
  const [noResource, setNoResource] = useState(false);
  const [selectedPlanLocation, setPlanLocataion] = useState("");
  // const [selectedPlan, setPlan] = useState({});
  const [plans, setPlans] = useState(); // TODO: set init value in useEffect

  const [isToggle, setToggle] = useState(false);
  const [isServerChange, setServerChange] = useState(false);
  const [planIndex, setIndex] = useState(-1);
  const router = useRouter();
  const [activeIndex, setActiveIndex] = useState(0);

  useEffect(() => {
    const fetchData = async () => {
      // const response = await Client.query(
      //   Prismic.Predicates.at("document.id", "linux-shared-hosting")
      // );
      // const response = await Client.query("");

      const { productslug } = router.query;

      if (productslug) {
        console.log("Slug :", router.query);

        const response = await Client.getByUID("products", productslug);
        if (response) {
          let ProductD = {};
          console.log("response=>LLLL", response);

          let data = response.data;

          ProductD.id = response.uid;
          ProductD.title = data?.title[0].text;
          // ProductD.slug = data?.slug && data.slug[0].text;
          ProductD.desc = data?.desc && data.desc[0].text;
          ProductD.type = data?.type;
          ProductD.category = data?.category;
          ProductD.bannerTheme = data?.theme;
          ProductD.theme = "#3AC6AD";
          ProductD.img = data?.img?.url;
          ProductD.featured = data?.featured;
          ProductD.sale = data?.sale;

          let newLocation = {
            usa: false,
            ind: false,
            sin: false,
            uk: false,
            ger: false,
            kor: false,
            jpn: false,
            mal: false,
            esp: false,
            fra: false,
          };

          data?.locations &&
            data.locations.forEach((loc) => {
              // console.log(loc["locations-select"]);
              if (Object.keys(newLocation).includes(loc["locations-select"])) {
                newLocation[loc["locations-select"]] = true;
              }
            });
          ProductD.locations = newLocation;

          ProductD["plans-list"] = data?.["plans-list"];
          // ProductD["plans-duration"] = data?.["plans-duration"];

          ProductD &&
            ProductD["plans-list"].forEach((item, i) => {
              ProductD["plans-list"][i]["plans-durations"] =
                data?.["plans-duration"];
            });

          //Todo need to uncomment this
          // ProductD["plans-list"] = data?.["plans-list"];

          ProductD["why-title"] = data?.["why-title"][0].text;
          ProductD["why-item"] = data?.["why-item"];

          ProductD["techspecs-title"] = data?.["techspecs-title"][0].text;

          ProductD["techspecs-item"] = data?.["techspecs-item"];

          ProductD["features-title"] = data?.["features-title"][0].text;
          ProductD["features-list"] = data?.["features-list"];

          ProductD["faq-list"] = data?.["faq-list"];
          ProductD["faq-title"] = data?.["faq-title"][0].text;
          console.log("PDA", ProductD);

          setPlans(ProductD["plans-list"]);

          setPlanLocataion(Object.keys(ProductD.locations).find((el) => el));

          setProductData(ProductD);
        } else {
          setNoResource(true);
        }
      }
    };
    fetchData();
  }, [router.query]);

  let pageTheme = ProductData?.theme || "#3AC6AD";
  let bannerTheme = ProductData?.bannerTheme || "#3AC6AD";

  const handleServerLocation = (e) => {
    console.log(e);
    setPlanLocataion(e.target.value);
    setServerChange((prev) => !prev);

    setTimeout(() => {
      setServerChange((prev) => !prev);
    }, 300);
  };
  const toggleDropdown = (index) => {
    console.log(">>", index);
    // setPlanLocataion(e.target.value);
    setIndex(index);
    setToggle((prev) => !prev);
  };

  const handlePlan = (planIndex, durationIndex) => {
    let newDurations = plans[planIndex]["plans-durations"].map((dur, i) => {
      if (i === durationIndex) {
        dur["plans-duration-selected"] = true;
      } else {
        dur["plans-duration-selected"] = false;
      }

      return dur;
    });

    let newPlans = plans;

    newPlans[planIndex]["plan-durations"] = newDurations;

    console.log(newPlans);

    setIndex(-1);
    setToggle((prev) => !prev);

    setPlans(newPlans);
  };

  // .btn-primary {
  //   background: ${pageTheme};
  //   border-color: ${pageTheme};
  // }
  // .select {
  //   background: ${pageTheme};
  //   border-color: ${pageTheme};
  // }
  return (
    <Layout ProductData={ProductData}>
      <style jsx>{`
      

        .bg-info,
        .nav-pills .nav-link.active {
          background: ${pageTheme} !important;
        }
        .text-info,
        .exclusive .pricing-header,
        .header .topbar .social ul li a.colour {
          color: ${pageTheme} !important;
        }
        .btn-outline-primary {
          border-color: ${pageTheme};
          color: ${pageTheme} !important;
        }
        .widget_angel,
        .badge-parent .badge {
          background: ${pageTheme};
        }
        .widget_angel:before {
          border-top: 35px solid ${pageTheme};
        }
        .widget_angel:after {
          border-bottom: 35px solid ${pageTheme};
        }
        .nav-pills .nav-link.active:after {
          border-top: 15px solid ${pageTheme};
        }
        .pricing-switcher input[type="radio"]:checked + label img {
          border: 3px solid ${pageTheme};
        }
      `}</style>

      {ProductData ? (
        <>
          <section className="slider-03">
            <div id="main-slider" className="swiper-container">
              <div className="swiper-wrapper">
                <div
                  className="swiper-slide slide-01"
                  style={{
                    background: `linear-gradient(178.82deg, ${bannerTheme} -0.79%, #FFFFFF 112.21%)`,
                  }}
                >
                  <div className="container ">
                    <div className="row d-flex justify-content-center">
                      <div
                        className="col-lg-6 col-md-12 col-sm-12 align-self-start text-center"
                        style={{
                          background:
                            "url(/images/promo-1_bg.png) center / cover",
                        }}
                        data-swiper-animation="fadeInUp"
                        data-duration="2.0s"
                        data-delay="0.2s"
                      >
                        <img
                          className="img-fluid"
                          data-swiper-animation="fadeInDown"
                          data-duration="2.0s"
                          data-delay="0.2s"
                          src={ProductData?.img}
                          alt="#"
                        />
                      </div>
                      <div className="col-lg-6 col-md-12 col-sm-12 text-left  align-self-center pb-5">
                        <div className="banner-content">
                          <div className="">
                            <h2
                              className="animated mb-0 text-dark h1"
                              data-swiper-animation="fadeInDown"
                              data-duration="2.0s"
                              data-delay="0.6s"
                            >
                              {ProductData?.title}
                            </h2>
                            <h6
                              className="text-dark mb-0 fnt-20 font-weight-light pb-3"
                              data-swiper-animation="fadeInDown"
                              data-duration="2.0s"
                              data-delay="0.4s "
                            >
                              {ProductData?.desc}
                            </h6>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>

          <section className="margin-n-tp-60">
            <div
              className="bg-white container position-relative z-index-99 "
              style={{
                overflow: "hidden",
                borderTopLeftRadius: "5px",
                borderTopRightRadius: "5px",
              }}
            >
              <div className="row">
                <div className="col-md-6 col-lg-12 mb-md-3  pb-sm-0 pb-2 px-0 ">
                  <div className="pricing-container">
                    <div className="pricing-switcher pt-3 ">
                      <p className="fieldset">
                        <span className="float-left fnt-14 padd-h-20 pt-2 text-black">
                          Change Server Location
                        </span>
                        {ProductData?.locations &&
                          Object.keys(ProductData.locations).map(
                            (lkey) =>
                              ProductData.locations[lkey] && (
                                <>
                                  <input
                                    type="radio"
                                    name={lkey}
                                    value={lkey}
                                    id={lkey}
                                    onClick={(e) => {
                                      console.log("Log");
                                      handleServerLocation(e);
                                    }}
                                    checked={selectedPlanLocation === lkey}
                                  />
                                  <label htmlFor={lkey}>
                                    <img
                                      src={`/images/locations/${lkey}.png`}
                                      width="40"
                                    />
                                  </label>
                                </>
                              )
                          )}

                        <span className="switch"></span>
                      </p>
                    </div>
                    {/* here  */}
                    <ul className="pricing-list bounce-invert">
                      {plans &&
                        plans.map((plan, idxPlan) => {
                          let selectedPlan = plan["plans-durations"].find(
                            (el) => el["plans-duration-selected"]
                          );
                          // console.log("selectedPlan=>>>>>>>>:", selectedPlan);
                          return (
                            <li
                              className={`${
                                plan?.["plan-popular"] && "exclusive"
                              }`}
                            >
                              <ul
                                className={`pricing-wrapper ${
                                  isServerChange && "is-switched"
                                }`}
                              >
                                <li
                                  data-type="india"
                                  className={`is-visible is-ended  ${
                                    plan?.["plan-popular"] && "text-center"
                                  }`}
                                >
                                  {plan?.["plan-popular"] && (
                                    <div className="mostpopuler bg-inf0 bg-info dis-in-blk padd-h-40 padd-v-5 text-white">
                                      MOST POPULAR
                                    </div>
                                  )}
                                  <header className="pricing-header">
                                    <h2 className="mt-3 text-uppercase mb-0">
                                      {plan?.["plan-title"][0].text}
                                    </h2>
                                    <p className="text-info">
                                      {plan?.["plan-desc"][0].text}
                                    </p>
                                    <a
                                      className={`d-flex marg-h-35 price priceselected  ${
                                        !isToggle &&
                                        planIndex === idxPlan &&
                                        "open"
                                      } `}
                                      onClick={() => {
                                        toggleDropdown(idxPlan);
                                      }}
                                    >
                                      <input type="hidden" value="" />

                                      <div className="w-75">
                                        <h5 className="fnt-16 no-marg">
                                          {
                                            selectedPlan?.[
                                              "plans-duration-title"
                                            ]?.[0].text
                                          }{" "}
                                          @{" "}
                                          {
                                            selectedPlan?.[
                                              "plans-duration-currency"
                                            ]
                                          }
                                          {
                                            selectedPlan?.[
                                              "plans-duration-rate"
                                            ]
                                          }
                                          {selectedPlan?.["plans-duration-per"]}
                                        </h5>
                                        <del className="d-block fnt-16 text-left fadeInUp animated">
                                          {
                                            selectedPlan?.[
                                              "plans-duration-currency"
                                            ]
                                          }

                                          {
                                            selectedPlan?.[
                                              "plans-duration-sale"
                                            ]
                                          }

                                          {selectedPlan?.["plans-duration-per"]}
                                        </del>
                                        <p className="fnt-12 no-marg text-left text-light-gray">
                                          {
                                            selectedPlan?.[
                                              "plans-duration-renew-title"
                                            ][0].text
                                          }{" "}
                                          {
                                            selectedPlan?.[
                                              "plans-duration-currency"
                                            ]
                                          }
                                          {
                                            selectedPlan?.[
                                              "plans-duration-renew-rate"
                                            ]
                                          }
                                          {selectedPlan?.["plans-duration-per"]}
                                        </p>
                                      </div>

                                      <div className="mt-2 shape-button">
                                        <svg
                                          width="16"
                                          height="20"
                                          viewBox="0 0 16 24"
                                          fill="none"
                                          xmlns="http://www.w3.org/2000/svg"
                                          className="d-block ml-auto mr-3 mb-4"
                                        >
                                          <path
                                            d="M7.64647 23.8535L0.146472 16.3535C0.00387798 16.2099 -0.0395753 15.9966 0.0380497 15.8086C0.115206 15.6216 0.297831 15.5 0.499956 15.5L1.49994 15.5C1.63274 15.5 1.75972 15.5527 1.85347 15.6465L6.99997 20.793L6.99997 0.500016C7.00002 0.223641 7.22361 3.15755e-07 7.49999 3.27836e-07L8.49997 3.71547e-07C8.77635 3.83628e-07 8.99999 0.223641 8.99999 0.500016L8.99999 20.793L14.1465 15.6465C14.2402 15.5528 14.3672 15.5 14.5 15.5L15.5 15.5C15.7022 15.5 15.8848 15.6216 15.9619 15.8086C15.9878 15.8706 16 15.9355 16 16C16 16.1299 15.9493 16.2578 15.8535 16.3535L8.35353 23.8535C8.1582 24.0488 7.8418 24.0488 7.64647 23.8535Z"
                                            fill="black"
                                          ></path>
                                        </svg>

                                        <span className="fnt-14 font-weight-light pab text-white widget_angel">
                                          {selectedPlan?.[
                                            "plans-duration-savetext"
                                          ][0].text +
                                            ` ` +
                                            selectedPlan?.[
                                              "plans-duration-save"
                                            ]}{" "}
                                          %
                                        </span>
                                      </div>
                                    </a>

                                    <ul
                                      className={`pricedropdown p-0  ${
                                        isToggle &&
                                        planIndex === idxPlan &&
                                        "active"
                                      }`}
                                    >
                                      {plan?.["plans-durations"] &&
                                        plan["plans-durations"].map(
                                          (duration, idxDuration) =>
                                            !duration[
                                              "plans-duration-selected"
                                            ] && (
                                              <li
                                                onClick={() => {
                                                  console.log(
                                                    "selected Duration >>>>",
                                                    duration
                                                  );
                                                  handlePlan(
                                                    planIndex,
                                                    idxDuration
                                                  );
                                                }}
                                              >
                                                <div className="d-flex marg-h-35 price">
                                                  <div className="w-75">
                                                    <h5 className="fnt-16 no-marg">
                                                      {
                                                        duration[
                                                          "plans-duration-title"
                                                        ]?.[0].text
                                                      }{" "}
                                                      @{" "}
                                                      {
                                                        duration[
                                                          "plans-duration-currency"
                                                        ]
                                                      }
                                                      {
                                                        duration[
                                                          "plans-duration-rate"
                                                        ]
                                                      }
                                                      {
                                                        duration[
                                                          "plans-duration-per"
                                                        ]
                                                      }
                                                    </h5>
                                                    <del className="d-block fnt-16 text-left fadeInUp animated">
                                                      {
                                                        duration[
                                                          "plans-duration-currency"
                                                        ]
                                                      }

                                                      {
                                                        duration[
                                                          "plans-duration-sale"
                                                        ]
                                                      }

                                                      {
                                                        duration[
                                                          "plans-duration-per"
                                                        ]
                                                      }
                                                    </del>
                                                    <p className="fnt-12 no-marg text-left text-light-gray">
                                                      {
                                                        duration[
                                                          "plans-duration-renew-title"
                                                        ][0].text
                                                      }{" "}
                                                      {
                                                        duration[
                                                          "plans-duration-currency"
                                                        ]
                                                      }
                                                      {
                                                        duration[
                                                          "plans-duration-renew-rate"
                                                        ]
                                                      }
                                                      {
                                                        duration[
                                                          "plans-duration-per"
                                                        ]
                                                      }
                                                    </p>
                                                  </div>
                                                  <div className="mt-2 shape-button">
                                                    <svg
                                                      version="1.1"
                                                      id="Capa_1"
                                                      xmlns="http://www.w3.org/2000/svg"
                                                      xlink="http://www.w3.org/1999/xlink"
                                                      x="0px"
                                                      y="0px"
                                                      width="16"
                                                      height="20"
                                                      viewBox="0 0 174.239 174.239"
                                                      space="preserve"
                                                      className="d-block ml-auto mr-3 mb-4"
                                                    >
                                                      <g>
                                                        <path d="M0,0v174.239h174.239V0H0z M159.305,159.305H14.935V14.935h144.37V159.305z" />
                                                        <polygon
                                                          className="arrow"
                                                          points="135.016,61.47 123.494,51.97 78.041,107.091 49.651,84.319 40.307,95.968 80.189,127.957 	"
                                                        />
                                                      </g>
                                                    </svg>

                                                    <span className="fnt-14 font-weight-light pab text-white widget_angel">
                                                      {duration[
                                                        "plans-duration-savetext"
                                                      ][0].text +
                                                        ` ` +
                                                        duration[
                                                          "plans-duration-save"
                                                        ]}{" "}
                                                      %
                                                    </span>
                                                  </div>
                                                </div>
                                              </li>
                                            )
                                        )}
                                    </ul>
                                  </header>

                                  <div className="pricing-body">
                                    <ul className="pricing-features">
                                      {plan?.["plan-features"] &&
                                        plan["plan-features"].map((feature) => (
                                          <li>{feature.text}</li>
                                        ))}
                                    </ul>
                                  </div>
                                  <footer className="pricing-footer">
                                    <a
                                      className="select"
                                      href={plan?.["plan-cta-link"].url}
                                    >
                                      {plan?.["plan-cta-text"][0].text}
                                    </a>
                                  </footer>
                                </li>
                              </ul>
                            </li>
                          );
                        })}
                    </ul>
                  </div>
                </div>
              </div>
            </div>
            <div className="d-flex justify-content-center text-center py-5">
              <div className="padd-h-20">
                <svg
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <circle cx="12" cy="12" r="12" fill={pageTheme} />
                  <line
                    x1="12"
                    y1="5"
                    x2="12"
                    y2="19"
                    stroke="white"
                    strokeWidth="2"
                  />
                  <line
                    x1="19"
                    y1="12"
                    x2="5"
                    y2="12"
                    stroke="white"
                    strokeWidth="2"
                  />
                </svg>
              </div>
              <div>
                <span className="text-info">Available Add Ons: </span>Dedicated
                IP @ $2.99 | 1GB RAM @ $1.00 | 1 Core CPU @ $2.00
              </div>
            </div>
          </section>

          <section className="marg-tp-30">
            <div className="bg-white container position-relative pt-3 z-index-99 simple_shadow bdr-radius-5">
              <div className="row pt-4">
                <div className="col-12">
                  <div className="section-title ml-4">
                    <div className="ml-4 mt-3 shape-button">
                      <span className="fnt-18 font-weight-light pab text-white widget_angel">
                        Powering 500,000+ Web Professionals Globally
                      </span>
                    </div>

                    <h2 className="mt-3 text-uppercase">
                      {ProductData?.["why-title"]}
                    </h2>
                  </div>
                </div>
              </div>
              <div className="row pb-5">
                {ProductData?.["why-title"] &&
                  ProductData["why-item"].map((item) => (
                    //     hover: item["why-item-hove-text"][0].text,
                    <div className="col-lg-3 col-md-6 mb-md-0 mb-4 bdr-rgt-1 bdr-btm-1">
                      <div className="feature-info feature-info-style-1">
                        <div className="feature-info-icon">
                          <img src={item["why-item-icon"].url} />
                        </div>
                        <div className="feature-info-content">
                          <h6 className="feature-info-title text-black">
                            {item["why-item-title"][0].text}
                          </h6>
                          <p className="feature-info-title line-hght-22 ">
                            {item["why-item-desc"][0].text}
                          </p>
                        </div>
                      </div>
                    </div>
                  ))}
              </div>
            </div>
          </section>

          <section className="marg-tp-30">
            <div className="bg-white container position-relative pt-3 z-index-99 simple_shadow bdr-radius-5">
              <div className="row pt-4">
                <div className="col-12">
                  <div className="section-title ml-4">
                    <div className="ml-4 mt-3 shape-button">
                      <span className="fnt-18 font-weight-light pab text-white widget_angel">
                        Technical Specifications
                      </span>
                    </div>

                    <h2 className="mt-3 text-uppercase">
                      {ProductData?.["techspecs-title"]}
                    </h2>
                  </div>
                </div>
              </div>
              <div className="row pb-5">
                {ProductData?.["techspecs-item"] &&
                  ProductData?.["techspecs-item"].map((item) => (
                    <div className={`col-lg-3 col-md-6 mb-md-0 mb-4 bdr-rgt-1`}>
                      <div className="feature-info feature-info-style-1">
                        <div className="feature-info-content">
                          <h6 className="feature-info-title text-black">
                            {item["techspecs-item-title"][0].text}
                          </h6>
                          {item?.["techspecs-item-list"] &&
                            item["techspecs-item-list"].map((item) => (
                              <p className="feature-info-title line-hght-22 mb-2">
                                {item.text}
                              </p>
                            ))}
                        </div>
                      </div>
                    </div>
                  ))}

                {/* <div className="col-lg-12 col-md-6 mb-4 mb-md-0 mt-4 pt-5 text-center ">
                  <a className="btn btn-primary btn-md mr-2 mr-xl-0" href="#">
                    <svg
                      width="24"
                      height="24"
                      viewBox="0 0 24 24"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                    >
                      <circle cx="12" cy="12" r="12" fill={pageTheme}></circle>
                      <line
                        x1="12"
                        y1="5"
                        x2="12"
                        y2="19"
                        stroke="white"
                        strokeWidth="2"
                      ></line>
                      <line
                        x1="19"
                        y1="12"
                        x2="5"
                        y2="12"
                        stroke="white"
                        strokeWidth="2"
                      ></line>
                    </svg>{" "}
                VIEW ALL{" "}
                  </a>
                </div>
             */}
              </div>
            </div>
          </section>

          <section className="marg-btm-100 marg-tp-30">
            <div className="bg-white container pt-3 z-index-99 simple_shadow bdr-radius-5 padd-btm-30">
              <div className="row pt-4">
                <div className="col-12">
                  <div className="section-title ml-4">
                    <h2 className="mt-3 text-uppercase">
                      {ProductData?.["features-title"]}
                    </h2>
                  </div>
                </div>
              </div>

              <div className="row pb-5">
                <div className="col-lg-12 col-md-12 px-5">
                  <div className="row ">
                    <div className="col-md-12 col-lg-12 col-xl-12">
                      <div
                        className="nav nav-pills  d-flex"
                        id="v-pills-tab"
                        role="tablist"
                        aria-orientation="vertical"
                      >
                        {ProductData?.["features-list"] &&
                          ProductData["features-list"].map((item, i) => (
                            <a
                              className={`nav-link  col text-center ${
                                i === 0 && "active"
                              }`}
                              id={`v-pills-${i}-tab`}
                              data-toggle="pill"
                              href={`#v-pills-${i}`}
                              role="tab"
                              aria-controls={`v-pills-${i}`}
                              aria-selected="true"
                              onClick={() => {
                                setActiveIndex(i);
                              }}
                            >
                              {activeIndex === i  ? (
                                <img
                                  className="img-fluid"
                                  src={item["feature-list-icon"].url}
                                />
                              ) : (
                                <img
                                  className="img-fluid"
                                  src={item["feature-list-icon-dark"]?.url}
                                />
                              )}
                              {/* <svg
                                width="80"
                                height="80"
                                viewBox="0 0 80 80"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                              >
                                <g>
                                  <path d="M76.9386 33.6616H75.5104C74.214 26.4509 70.7643 19.8127 65.4738 14.5227C58.628 7.6764 49.5252 3.90625 39.8438 3.90625C30.1624 3.90625 21.0596 7.6764 14.2139 14.5227C8.88552 19.8511 5.42298 26.5467 4.14857 33.8184H2.74903C1.14685 33.8184 -0.15625 35.1215 -0.15625 36.7237V47.2816C-0.15625 48.8832 1.14685 50.1869 2.74903 50.1869H5.01527C6.9507 56.9081 10.81 62.9963 16.236 67.6576C16.7273 68.0794 17.4677 68.0238 17.89 67.5325C18.3124 67.0405 18.2563 66.3002 17.7649 65.8778C16.3611 64.6724 15.0702 63.3638 13.8977 61.9697C15.6909 61.2141 17.5232 60.5909 19.3689 60.0801C20.2454 61.6267 21.2287 63.119 22.3194 64.5442C24.7089 67.6674 27.4073 70.4152 30.2833 72.6802C27.8937 71.9801 25.5829 71.0182 23.4034 69.8067C22.837 69.4923 22.1228 69.6962 21.8085 70.2626C21.4936 70.829 21.6974 71.5431 22.2638 71.8581C27.6111 74.8286 33.6903 76.3991 39.8438 76.3991C49.5252 76.3991 58.6274 72.6289 65.4738 65.7826C69.8714 61.3856 72.9957 56.0554 74.6706 50.2406H76.9386C78.5408 50.2406 79.8439 48.9375 79.8439 47.3353V36.5668C79.8439 34.9653 78.5408 33.6616 76.9386 33.6616ZM73.1221 33.6616H64.9617C64.864 33.0536 64.756 32.4457 64.6302 31.8384C63.9332 28.4736 62.8437 25.2607 61.3795 22.2278C61.5956 22.1686 61.8129 22.1106 62.0277 22.0496C63.5212 21.6224 65.4225 21.0413 67.2902 20.2423C70.207 24.2469 72.1864 28.8111 73.1221 33.6616ZM62.61 33.8184H50.4884C50.4481 33.23 50.4041 32.6417 50.3523 32.0545C50.1197 29.43 49.7767 26.8891 49.3348 24.4593C52.6972 24.1101 55.9449 23.5639 59.0608 22.8229C60.547 25.8069 61.6426 28.982 62.3329 32.3145C62.4366 32.815 62.5264 33.3167 62.61 33.8184ZM63.8148 16.1811C64.5057 16.872 65.1619 17.5885 65.785 18.3264C64.2225 18.9539 62.6503 19.4312 61.3826 19.7937C61.0151 19.8987 60.6453 19.9994 60.2742 20.0983C59.5326 18.769 58.7178 17.4768 57.8254 16.2268C55.4872 12.9529 52.7143 10.0867 49.5484 7.65565C54.8823 9.24134 59.77 12.1362 63.8148 16.1811ZM43.4614 6.4441C48.4431 9.2444 52.6338 12.9932 55.9162 17.5904C56.6316 18.5932 57.2938 19.6253 57.9066 20.6824C55.0093 21.3434 51.9947 21.8335 48.8764 22.1491C47.5184 15.8264 45.4615 10.3803 42.8852 6.38856C43.0775 6.40503 43.2697 6.42335 43.4614 6.4441ZM39.8438 6.25245C39.8725 6.25245 39.9006 6.25306 39.9293 6.25306C42.7796 10.0147 45.0587 15.6336 46.5266 22.3529C44.0205 22.5336 41.4533 22.6075 38.8294 22.569C37.0484 22.5434 35.1423 22.4878 33.158 22.367C34.6259 15.6415 36.9062 10.0171 39.7584 6.25306C39.7871 6.25306 39.8151 6.25245 39.8438 6.25245ZM36.8024 6.38856C34.2194 10.3894 32.1595 15.8521 30.8015 22.193C27.8565 21.9367 24.7815 21.5125 21.7054 20.8118C22.3389 19.7089 23.0262 18.6335 23.7714 17.5898C27.0539 12.9932 31.2446 9.2444 36.2263 6.44349C36.4179 6.42335 36.6102 6.40503 36.8024 6.38856ZM30.3437 24.5087C29.9061 26.9233 29.5661 29.4477 29.3354 32.0545C29.2835 32.6417 29.2396 33.23 29.1999 33.8184H17.0764C17.1595 33.3167 17.251 32.815 17.3548 32.3145C18.0347 29.0308 19.1101 25.9009 20.5628 22.9548C23.8746 23.7494 27.1833 24.2237 30.3437 24.5087ZM15.8728 16.1811C19.9176 12.1362 24.8053 9.24134 30.1392 7.65565C26.9727 10.0867 24.1999 12.9529 21.8622 16.2268C20.943 17.5141 20.1062 18.8471 19.3476 20.2192C17.5086 19.7095 15.6824 19.0876 13.8959 18.3344C14.5209 17.594 15.1795 16.875 15.8728 16.1811ZM12.3963 20.2448C14.3164 21.0877 16.2781 21.7786 18.2514 22.3456C16.8158 25.3443 15.7453 28.5169 15.0574 31.8384C14.9213 32.4976 14.8035 33.158 14.7003 33.8184H6.53505C7.4579 28.91 9.44887 24.2914 12.3963 20.2448ZM2.74903 47.8407C2.4408 47.8407 2.18995 47.5898 2.18995 47.281V36.7231C2.18995 36.4149 2.4408 36.164 2.74903 36.164H36.6114C37.2596 36.164 37.7845 35.6391 37.7845 34.9909C37.7845 34.3433 37.2596 33.8178 36.6114 33.8178H31.5504C31.587 33.299 31.6266 32.7796 31.6724 32.2614C31.905 29.6363 32.2492 27.1027 32.6935 24.6888C34.8334 24.8261 36.8842 24.8871 38.7958 24.9146C39.2585 24.9213 39.7199 24.925 40.1801 24.925C42.4946 24.925 44.7657 24.8383 46.9911 24.6698C47.4366 27.0893 47.7821 29.6296 48.0152 32.2614C48.061 32.7796 48.1013 33.299 48.1379 33.8178H43.9356C43.288 33.8178 42.7625 34.3433 42.7625 34.9909C42.7625 35.6391 43.288 36.164 43.9356 36.164H62.1315V47.8401H2.74903V47.8407ZM61.8501 50.1863C61.1744 52.7082 60.2394 55.1533 59.0535 57.48C55.9431 56.7408 52.7027 56.1933 49.3464 55.8442C49.6833 54.0101 49.9598 52.1192 50.1734 50.1869H61.8501V50.1863ZM47.8156 50.1863C47.6039 52.0497 47.3316 53.871 47.0014 55.6361C44.3305 55.4335 41.5937 55.3492 38.7958 55.3901C36.8806 55.4176 34.8261 55.4786 32.6826 55.6166C32.3542 53.8575 32.0832 52.0429 31.872 50.1863H47.8156ZM12.4036 60.0575C10.2246 57.0546 8.55715 53.7196 7.46278 50.1863H15.4169C16.0907 52.8694 17.0368 55.475 18.2508 57.9597C16.2799 58.5261 14.3207 59.2158 12.4036 60.0575ZM17.84 50.1863H29.5124C29.7242 52.1028 29.9988 53.9784 30.3321 55.7978C27.1766 56.0823 23.8733 56.5565 20.5677 57.3487C19.4135 55.0618 18.5028 52.6606 17.84 50.1863ZM36.2147 73.8539C31.8256 71.3814 27.6673 67.6729 24.1828 63.1184C23.2904 61.9532 22.4769 60.7386 21.7371 59.4856C24.8005 58.7898 27.862 58.368 30.7947 58.1123C31.2586 60.243 31.8085 62.2828 32.4421 64.2C33.3771 67.0253 34.845 70.7942 36.8189 73.9149C36.6175 73.8972 36.4161 73.8759 36.2147 73.8539ZM39.8438 74.0529C39.8151 74.0529 39.7871 74.0517 39.7584 74.0517C37.9114 71.6048 36.1549 67.9524 34.6699 63.4633C34.0931 61.7195 33.5895 59.8689 33.1586 57.9377C35.1429 57.8175 37.0484 57.7613 38.8294 57.7357C41.4533 57.6985 44.0199 57.7723 46.526 57.953C46.0957 59.8787 45.5927 61.7244 45.0178 63.4633C43.5334 67.9524 41.7762 71.6048 39.9293 74.0517C39.9006 74.0523 39.8725 74.0529 39.8438 74.0529ZM42.8663 73.9186C44.8414 70.7973 46.3105 67.0265 47.245 64.2C47.8748 62.2963 48.4211 60.2723 48.8825 58.1575C51.9874 58.4718 54.9885 58.9582 57.8736 59.615C57.1547 60.8223 56.3661 61.9935 55.5049 63.1184C52.0167 67.6771 47.8541 71.3887 43.4608 73.8612C43.263 73.882 43.0647 73.9009 42.8663 73.9186ZM63.8148 64.1237C59.7279 68.2106 54.7804 71.1232 49.3824 72.6973C52.2663 70.4292 54.9726 67.6753 57.3683 64.5442C58.4309 63.1563 59.3904 61.7036 60.2491 60.1997C60.6288 60.301 61.0072 60.4042 61.3826 60.511C62.649 60.8735 64.2201 61.3508 65.782 61.9777C65.1588 62.7156 64.5057 63.4334 63.8148 64.1237ZM67.2865 60.0612C65.42 59.2634 63.52 58.6824 62.0277 58.2557C61.8129 58.1941 61.5956 58.1367 61.3795 58.0775C62.613 55.5744 63.5731 52.9463 64.2567 50.2406H72.2182C71.1293 53.7519 69.4703 57.0631 67.2865 60.0612ZM77.4977 47.2816C77.4977 47.5898 77.2468 47.8407 76.9386 47.8407H64.4771V36.164H76.9386C77.2468 36.164 77.4977 36.4155 77.4977 36.7237V47.2816Z"></path>
                                  <path d="M8.72133 44.2712C8.72133 44.4446 8.46071 44.6265 8.15736 44.6265C7.82838 44.6265 7.60255 44.4446 7.60255 44.2712V38.4552C7.60255 38.2471 7.82838 38.1079 8.15736 38.1079C8.46071 38.1079 8.72133 38.2471 8.72133 38.4552V41.1157C8.87697 40.7782 9.26699 40.4572 9.81325 40.4572C10.6104 40.4572 11.3037 41.2549 11.3037 42.2168V44.2706C11.3037 44.505 11.0181 44.6265 10.7404 44.6265C10.4804 44.6265 10.1856 44.505 10.1856 44.2706V42.2168C10.1856 41.8268 9.83889 41.4368 9.43178 41.4368C9.07656 41.4368 8.72072 41.731 8.72072 42.2168V44.2712H8.72133Z"></path>
                                  <path d="M13.7659 43.222C13.7659 43.5602 13.8874 43.6816 14.2517 43.6816H14.5899C14.9103 43.6816 15.0666 43.916 15.0666 44.1498C15.0666 44.3927 14.9103 44.6265 14.5899 44.6265H14.2517C13.2117 44.6265 12.6483 44.2017 12.6483 43.222V39.0186C12.6483 38.8104 12.9425 38.6719 13.2031 38.6719C13.4888 38.6719 13.7665 38.8104 13.7665 39.0186V40.509H14.7895C14.9713 40.509 15.0751 40.7172 15.0751 40.9167C15.0751 41.1243 14.9713 41.3239 14.7895 41.3239H13.7665V43.222H13.7659Z"></path>
                                  <path d="M17.2943 43.222C17.2943 43.5602 17.4152 43.6816 17.7796 43.6816H18.1177C18.4381 43.6816 18.5944 43.916 18.5944 44.1498C18.5944 44.3927 18.4381 44.6265 18.1177 44.6265H17.7796C16.7395 44.6265 16.1762 44.2017 16.1762 43.222V39.0186C16.1762 38.8104 16.471 38.6719 16.731 38.6719C17.0172 38.6719 17.2943 38.8104 17.2943 39.0186V40.509H18.3173C18.4992 40.509 18.6029 40.7172 18.6029 40.9167C18.6029 41.1243 18.4992 41.3239 18.3173 41.3239H17.2943V43.222Z"></path>
                                  <path d="M20.7703 40.8558V41.1158C20.9693 40.7783 21.3855 40.4573 21.9404 40.4573C22.8071 40.4573 23.4919 41.255 23.4919 42.2169V42.9274C23.4919 43.8551 22.7814 44.7047 21.9751 44.7047C21.4551 44.7047 21.0041 44.3751 20.8399 44.0199V46.1867C20.8399 46.3685 20.5799 46.5419 20.2674 46.5419C19.9469 46.5419 19.7217 46.3685 19.7217 46.1867V40.8558C19.7217 40.6477 19.9555 40.5092 20.2503 40.5092C20.5536 40.5092 20.7703 40.6477 20.7703 40.8558ZM22.3737 42.2169C22.3737 41.8269 22.0185 41.4369 21.5851 41.4369C21.2214 41.4369 20.8399 41.7311 20.8399 42.2169V43.0836C20.8399 43.2655 21.1603 43.7251 21.6022 43.7251C22.0099 43.7251 22.3737 43.3265 22.3737 42.9274V42.2169Z"></path>
                                  <path d="M26.6736 43.4822C26.6736 42.7199 24.6192 43.1965 24.6192 41.7488C24.6192 41.1335 25.0092 40.4573 26.1707 40.4573C26.8732 40.4573 27.5489 40.7002 27.5489 41.0206C27.5489 41.1769 27.4018 41.5584 27.1418 41.5584C26.9336 41.5584 26.6651 41.3069 26.1884 41.3069C25.7551 41.3069 25.5817 41.5236 25.5817 41.6969C25.5817 42.3298 27.6618 41.8965 27.6618 43.4388C27.6618 44.2109 27.0899 44.7047 26.0669 44.7047C25.1832 44.7047 24.4983 44.3403 24.4983 43.9589C24.4983 43.777 24.654 43.4651 24.8707 43.4651C25.1221 43.4651 25.3132 43.8551 26.0413 43.8551C26.5522 43.8551 26.6736 43.6555 26.6736 43.4822Z"></path>
                                  <path d="M29.9592 41.5584C29.9592 41.8702 29.6906 42.1473 29.3787 42.1473C29.0406 42.1473 28.7891 41.8702 28.7891 41.5584C28.7891 41.2373 29.0406 40.9688 29.3787 40.9688C29.6906 40.9688 29.9592 41.2373 29.9592 41.5584ZM29.9592 44.0889C29.9592 44.4014 29.6906 44.6785 29.3787 44.6785C29.0406 44.6785 28.7891 44.4014 28.7891 44.0889C28.7891 43.7684 29.0406 43.4999 29.3787 43.4999C29.6906 43.4999 29.9592 43.7684 29.9592 44.0889Z"></path>
                                  <path d="M34.9085 38.3339C34.9085 38.3857 34.9 38.4376 34.8737 38.4895L31.7621 44.7828C31.7011 44.9037 31.5626 44.9733 31.424 44.9733C31.1725 44.9733 31.0078 44.7743 31.0078 44.5918C31.0078 44.5399 31.0255 44.488 31.0511 44.4447L34.1627 38.1257C34.2237 38.0043 34.3452 37.9438 34.4752 37.9438C34.6833 37.9438 34.9085 38.0995 34.9085 38.3339Z"></path>
                                  <path d="M37.5269 38.3339C37.5269 38.3857 37.5178 38.4376 37.4921 38.4895L34.38 44.7828C34.3195 44.9037 34.181 44.9733 34.0424 44.9733C33.791 44.9733 33.6262 44.7743 33.6262 44.5918C33.6262 44.5399 33.6433 44.488 33.6695 44.4447L36.7811 38.1257C36.8421 38.0043 36.963 37.9438 37.0936 37.9438C37.3011 37.9438 37.5269 38.0995 37.5269 38.3339Z"></path>
                                  <path d="M42.5373 44.5222C42.4763 44.6699 42.2858 44.7218 42.0954 44.7218C41.8787 44.7218 41.6877 44.6522 41.6358 44.5222L40.9681 42.6326L40.3095 44.5137C40.2576 44.6522 40.0495 44.7218 39.8328 44.7218C39.651 44.7218 39.4599 44.6699 39.3995 44.5137L38.0647 41.0902C38.0299 41.0206 38.0213 40.9687 38.0213 40.9254C38.0213 40.6569 38.4547 40.4658 38.7495 40.4658C38.8966 40.4658 39.0266 40.5262 39.0699 40.6477L39.9366 43.1092L40.5866 40.9681C40.6477 40.7692 40.7948 40.7429 40.9681 40.7429C41.1329 40.7429 41.2891 40.7692 41.3496 40.9681L41.991 43.1178L42.8663 40.6477C42.9096 40.5348 43.0311 40.4658 43.1873 40.4658C43.4644 40.4658 43.9069 40.6562 43.9069 40.934C43.9069 40.9858 43.8984 41.0463 43.8721 41.0902L42.5373 44.5222Z"></path>
                                  <path d="M49.0644 44.5222C49.004 44.6699 48.8136 44.7218 48.6225 44.7218C48.4059 44.7218 48.2154 44.6522 48.1629 44.5222L47.4958 42.6326L46.8366 44.5137C46.7848 44.6522 46.5772 44.7218 46.36 44.7218C46.1781 44.7218 45.9876 44.6699 45.9266 44.5137L44.5918 41.0902C44.557 41.0206 44.5484 40.9687 44.5484 40.9254C44.5484 40.6569 44.9818 40.4658 45.2766 40.4658C45.4237 40.4658 45.5537 40.5262 45.5976 40.6477L46.4643 43.1092L47.1144 40.9681C47.1748 40.7692 47.3225 40.7429 47.4958 40.7429C47.6606 40.7429 47.8163 40.7692 47.8767 40.9681L48.5182 43.1178L49.394 40.6477C49.4374 40.5348 49.5588 40.4658 49.7145 40.4658C49.9922 40.4658 50.4341 40.6562 50.4341 40.934C50.4341 40.9858 50.4255 41.0463 50.3993 41.0902L49.0644 44.5222Z"></path>
                                  <path d="M55.5922 44.5222C55.5317 44.6699 55.3413 44.7218 55.1503 44.7218C54.9336 44.7218 54.7432 44.6522 54.6907 44.5222L54.0236 42.6326L53.3644 44.5137C53.3125 44.6522 53.1044 44.7218 52.8877 44.7218C52.7058 44.7218 52.5154 44.6699 52.4543 44.5137L51.1195 41.0902C51.0847 41.0206 51.0761 40.9687 51.0761 40.9254C51.0761 40.6569 51.5095 40.4658 51.8043 40.4658C51.9514 40.4658 52.0814 40.5262 52.1253 40.6477L52.9921 43.1092L53.6421 40.9681C53.7025 40.7692 53.8496 40.7429 54.0229 40.7429C54.1877 40.7429 54.344 40.7692 54.4044 40.9681L55.0459 43.1178L55.9218 40.6477C55.9645 40.5348 56.0866 40.4658 56.2422 40.4658C56.5193 40.4658 56.9618 40.6562 56.9618 40.934C56.9618 40.9858 56.9533 41.0463 56.927 41.0902L55.5922 44.5222Z"></path>
                                  <path d="M74.3971 39.5001L73.1319 39.3164L72.5661 38.1696C72.267 37.5641 71.6627 37.1887 70.9877 37.1887C70.3126 37.1887 69.7078 37.5647 69.4093 38.1696L68.8435 39.3164L67.5783 39.5001C66.9099 39.5972 66.3661 40.0562 66.1574 40.6976C65.9486 41.3397 66.1195 42.0313 66.6029 42.5025L67.5184 43.3948L67.3024 44.6552C67.1876 45.3198 67.4562 45.9796 68.0025 46.3764C68.5481 46.7731 69.2579 46.825 69.8561 46.5106L70.9877 45.9155L72.1193 46.5106C72.3793 46.6467 72.6601 46.7145 72.9402 46.7145C73.3034 46.7145 73.6647 46.6004 73.9729 46.3764C74.5186 45.9796 74.7871 45.3198 74.673 44.6552L74.4569 43.3948L75.3725 42.5025C75.8559 42.0313 76.0262 41.3397 75.818 40.6976C75.6093 40.0562 75.0648 39.5972 74.3971 39.5001ZM72.5984 41.9299C72.184 42.3346 71.9948 42.9169 72.0924 43.4876L72.1602 43.8812L71.8068 43.6957C71.2941 43.4259 70.6819 43.4259 70.1686 43.6957L69.8152 43.8812L69.8823 43.4876C69.9806 42.9169 69.7914 42.3346 69.3764 41.9299L69.0907 41.651L69.4856 41.5936C70.0587 41.5106 70.5543 41.1505 70.8113 40.6311L70.9877 40.2728L71.1647 40.6311C71.421 41.1505 71.9166 41.5106 72.4898 41.5936L72.8847 41.651L72.5984 41.9299Z"></path>
                                </g>
                                <defs>
                                  <clipPath id="clip0">
                                    <rect
                                      width="80"
                                      height="80"
                                      fill="white"
                                    ></rect>
                                  </clipPath>
                                </defs>
                              </svg>
                              */}
                              <span className="d-block pt-3">
                                {item["features-list-title"][0].text}
                              </span>
                            </a>
                          ))}
                      </div>
                    </div>
                    <div className="col-md-12 col-lg-12 col-xl-12">
                      <div className="tab-content" id="v-pills-tabContent">
                        {ProductData?.["features-list"] &&
                          ProductData["features-list"].map((item, i) => (
                            <div
                              className={`tab-pane fade ${
                                i === 0 && "active show"
                              }`}
                              id={`v-pills-${i}`}
                              role="tabpanel"
                              aria-labelledby={`v-pills-${i}-tab`}
                            >
                              <div className="align-items-center row">
                                <div className="col-lg-6 mb-lg-0 mb-4">
                                  <h2 className="mt-3 ">
                                    {item["feature-list-long"][0].text}
                                  </h2>
                                  <p>{item["feature-list-desc"][0].text}</p>
                                </div>

                                <div className="col-lg-6 mb-lg-0 text-center">
                                  <img
                                    src={item["feature-list-img"].url}
                                    className="img-fluid"
                                  />
                                </div>
                              </div>
                            </div>
                          ))}
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </section>

          <section className="marg-btm-100 ">
            <div className="bg-white container pt-3 z-index-99 simple_shadow bdr-radius-5 padd-btm-30">
              <div className="row pt-4">
                <div className="col-12">
                  <div className="section-title ml-4">
                    <h2 className="mt-3 text-uppercase">
                      {ProductData?.["faq-title"]}
                    </h2>
                  </div>
                </div>
              </div>

              <div className="row pb-5">
                <div className="col-lg-12 col-md-12 px-4">
                  <div
                    className="accordion accordion-style"
                    id="accordion-item"
                  >
                    {ProductData?.["faq-list"].map((faq, i) => (
                      <div className="card">
                        <div
                          className="accordion-icon card-header"
                          // id="one-accordion-item"
                          id={`one-accordion-item-${i}`}
                        >
                          <h6 className="mb-0">
                            <a
                              href="#"
                              className={`btn feature-info-title text-black ${
                                i !== 0 && "collapsed"
                              }`}
                              data-toggle="collapse"
                              data-target={`#collapse-one-accordion-item-${i}`}
                              aria-expanded={i === 0 && true}
                              aria-controls={`collapse-one-accordion-item-${i}`}
                            >
                              {faq["faq-list-item-question"][0].text}
                            </a>
                          </h6>
                        </div>
                        <div
                          // id="collapse-one-accordion-item"
                          id={`collapse-one-accordion-item-${i}`}
                          className={`collapse ${i === 0 && "show"}`}
                          // aria-labelledby="one-accordion-item"
                          aria-labelledby={`one-accordion-item-${i}`}
                          data-parent="#accordion-item"
                        >
                          <div className="card-body px-4">
                            <div className="row">
                              <div className="col-sm-12">
                                <p className="mb-0">
                                  {faq["faq-list-item-answer"][0].text}
                                </p>
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                    ))}
                  </div>
                </div>
              </div>
            </div>
          </section>
        </>
      ) : noResource ? (
        <ErrorPage />
      ) : (
        <div
          style={{
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
            height: "100vh",
          }}
        >
          <div class="spinner-grow text-info" role="status">
            <span class="sr-only">Loading...</span>
          </div>
        </div>
      )}
    </Layout>
  );
}
